@import url('https://fonts.googleapis.com/css2?family=Nunito:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;0,1000;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900;1,1000&display=swap')

body
  font-size: 16px
  font-family: 'Nunito', sans-serif !important

.xl-dashboard
  ul, li
    list-style-type: none
    padding: 0

  li
    border-radius: 7px

#jazzy-navbar
  margin-left: 0 !important

input[type="checkbox"]
  transform: scale(1.5)

.related-widget-wrapper
  button
    background: #0002
    border: 0
    border-radius: 8px

.statistics-dashboard
  background-color: #0003
  padding: .7rem .9rem .9rem .9rem
  border-radius: .4rem

.main-sidebar
  width: 270px

.sidebar-scroll
  &::-webkit-scrollbar
    display: none
    width: 0
    height: 0
  scrollbar-width: none
  -ms-overflow-style: none
  overflow: -moz-scrollbars-none

.object-tools
  padding: .3rem

.models-dashboard
  flex-wrap: wrap
  gap: .6rem

  & > div
    background-color: #0003
    padding: .7rem .9rem .9rem .9rem
    border-radius: .4rem
    height: min-content

    & > h5
      font-size: 1.5rem
      font-weight: bold
      margin-bottom: .7rem

    & a
      font-size: 1.2rem
      font-weight: 500

  .model-link
    transition: all 300ms ease-in-out
    text-decoration: none
    background-color: #fff1
    display: flex
    justify-content: center
    align-items: center
    border-radius: .3rem
    width: min-content
    white-space: nowrap
    padding: .1rem .4rem

    &:hover
      color: #fff !important
      background-color: rgba(80, 154, 255, 0.49)


#result_list
  select
    border-radius: .3rem
    padding: .1rem .3rem .2rem .3rem

.object-tools
  margin-bottom: 0

