JAZZMIN_SETTINGS = {
    'site_title': 'xlartas',
    'site_header': 'xlartas',
    'site_brand': 'xlartas',
    'site_logo': '/img/icon/logo.png',
    'site_logo_classes': '',
    'site_icon': '/img/icon/logo.png',
    'login_logo': '/img/icon/logo.png',
    'login_logo_dark': '/img/icon/logo.png',
    'welcome_sign': '',
    'copyright': 'xlartas © 2025',
    'show_sidebar': True,
    'navigation_expanded': True,
    'hide_apps': [],
    'hide_models': [],
    'order_with_respect_to': ['core'],
    'user_avatar': 'avatar',
    'related_modal_active': True,
    'custom_css': '/admin/css/jazzmin.css',
    'custom_js': '/admin/js/jazzmin.js',
    'theme': 'darkly',
    'dark_mode_theme': 'darkly',
    'navbar_small_text': False,
    'footer_small_text': False,
    'body_small_text': True,
    'brand_small_text': False,
    'brand_colour': 'navbar-dark',
    'accent': 'accent-lightblue',
    'navbar': 'navbar-dark',
    'no_navbar_border': False,
    'navbar_fixed': True,
    'layout_boxed': False,
    'footer_fixed': False,
    'sidebar_fixed': True,
    'sidebar': 'sidebar-dark-indigo',
    'sidebar_nav_small_text': False,
    'sidebar_disable_expand': True,
    'sidebar_nav_child_indent': False,
    'sidebar_nav_compact_style': False,
    'sidebar_nav_legacy_style': False,
    'sidebar_nav_flat_style': False,
    'button_classes': {
        'primary': 'btn-primary',
        'secondary': 'btn-secondary',
        'info': 'btn-info',
        'warning': 'btn-warning',
        'danger': 'btn-danger',
        'success': 'btn-success',
    },
    'actions_sticky_top': True,
    'usermenu_links': [
        {'name': 'Site', 'url': '', 'new_window': True},
        {'name': 'Logs', 'url': '', 'new_window': True},
        {'name': 'Swagger', 'url': '', 'new_window': True},
    ],
}

JAZZMIN_UI_TWEAKS = {
    'theme': 'darkly',
    'dark_mode_theme': 'darkly',
    'navbar': 'navbar-dark',
    'accent': 'accent-lightblue',
    'navbar_small_text': False,
    'sidebar': 'sidebar-dark-indigo',
    'sidebar_nav_small_text': False,
    'sidebar_disable_expand': True,
    'sidebar_nav_child_indent': False,
    'sidebar_nav_compact_style': True,
    'footer_fixed': False,
    'navbar_fixed': True,
    'actions_sticky_top': True,
}
